
# Arc Research Institute State Model Acceptable Use Policy

**_Last updated June 23, 2025_**

Arc Research Institute (the “**Institute**,” “**we**” or “**us**”) makes its State Model available and free to use for non-commercial purposes, subject to the terms of the [Arc Research Institute State Model Non-Commercial License](MODEL_LICENSE.md) (the “**License**”) and this Acceptable Use Policy (“**Policy**”). The purpose of this Policy is to ensure the State Model is used safely, ethically, and in accordance with all applicable laws and regulations. Any defined terms used but not defined in this Policy have the meaning given in the License. 

## Purpose and Permitted Use

The intent of the State Model is to support and enable research that advances knowledge and serves the public interest. This model is made available for use only by non-commercial entities such as government institutions, non-profit organizations, research institutes, and educational institutions.

Although the State Model may only be used for non-commercial purposes, you are free to use any outputs you create for any purpose. 

## Prohibited Uses

Unless otherwise expressly permitted pursuant to the License, you may not use the State Model, or any outputs or derivatives thereof, for any of the following purposes:

**1)  For-Profit Use:**
-  Use by or for any for-profit entity, including but not limited to corporations, partnerships, or other commercial organizations.
-  Use for any for-profit purpose, including but not limited to commercial research, sponsored research, product or service development, marketing, advertising, or any activity intended to generate revenue or commercial advantage.
-  For clarity, Outputs (as defined in the License) are not subject to this Section 1.

**2)  Unlawful, Harmful, or Unethical Activities:**
-  Any activity that violates applicable local, national, or international laws, rules, or regulations.
-  Any activity that causes or is intended to cause harm, including but not limited to the generation of offensive, abusive, or unlawful content.
-  Any use that infringes upon the rights of others, including invasion of privacy or jeopardizing the safety of others.

**3)  Misinforming or Misleading:**
-  Generation, dissemination, or promotion of false, incomplete, or otherwise misleading information.
-  Any use intended to deceive, misinform, or otherwise mislead individuals or organizations, including but not limited fabrication of data, fabrication or manipulation of outputs, impersonation, or to otherwise misrepresent facts or scientific findings.

**4)  Security and Privacy Violations:**
-  Introducing malware, viruses, or other malicious code.
-  Circumventing or attempting to circumvent any security or access controls.
-  Collecting, storing, or sharing sensitive, health, or personal data without proper authorization or consent.

**5)  Claiming Endorsement:**
-  Making any statements or claims or engaging in any other behavior or communication that indicates or suggests that the Institute endorses your use of the State Model, including any Derivative Works or Outputs (each as defined in the License). 

## Attribution

If You redistribute the State Model, or any outputs or derivatives thereof, you must also include a prominent and readable citation to the State Model research paper: Adduri, A. et al. (2025) Predicting cellular responses to perturbation across diverse contexts with State.

## Disclaimer

The State Model is provided AS IS and is intended for informational, theoretical, and research purposes only and is not intended for use in the diagnosis of disease or other conditions, or in the cure, mitigation, treatment, or prevention of disease. It should not be used or substituted for professional, medical advice.

## Third Party Integrations

The Institute is not responsible for the content, security, or privacy practices of any third-party technology, data, materials, or services that you may use in connection with the State Model. Use of such integrations is at your own risk and subject to the terms and policies of the respective third parties. The Institute disclaims any liability for damages or losses resulting from third-party integrations.

## Legal and Regulatory Compliance

The State Model may not be appropriate or available for use in some jurisdictions. Any use of the State Model is at your own risk, and you must comply with applicable laws, rules, and regulations in doing so. This includes, but is not limited to, data protection, privacy, and export control laws.  

## Enforcement and Disclaimer

Violation of this Policy may result in suspension or termination of the License and access to the State Model, and may subject you to legal liability. We reserve the right to investigate suspected violations and to cooperate with law enforcement authorities. The Institute disclaims liability for any misuse of or unauthorized training of the State Model.

## Contact

For questions about this Policy or to report suspected violations, please contact the State Model administrator at <info@arcinstitute.org>.
